@@ -23,7 +23,7 @@ use Params::Validate qw( :all );
 use POSIX qw( strftime );
 use Time::ParseDate;
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~[  OBJECT METHODS  ]~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
 
@@ -119,16 +119,16 @@ From source:
   $ tar xfz Apache2-WebApp-Plugin-DateTime-0.X.X.tar.gz
   $ perl MakeFile.PL PREFIX=~/path/to/custom/dir LIB=~/path/to/custom/lib
   $ make
-  $ make test     <--- Make sure you do this before contacting me
+  $ make test
   $ make install
 
 Perl one liner using CPAN.pm:
 
-  perl -MCPAN -e 'install Apache2::WebApp::Plugin::DateTime'
+  $ perl -MCPAN -e 'install Apache2::WebApp::Plugin::DateTime'
 
 Use of CPAN.pm in interactive mode:
 
-  $> perl -MCPAN -e shell
+  $ perl -MCPAN -e shell
   cpan> install Apache2::WebApp::Plugin::DateTime
   cpan> quit
 
